=== modified file 'NEWS'
--- NEWS	2007-08-07 02:12:43 +0000
+++ NEWS	2007-08-07 06:38:33 +0000
@@ -206,6 +206,9 @@
     * ``Repository`` objects can now be compared with ``==`` and ``!=`` to
       determine if they are the same repository.  (Andrew Bennetts)
 
+    * InterTree.compare now passes require_versioned on correctly.
+      (Marius Kruger)
+
   TESTING:
 
     * Remove selftest ``--clean-output``, ``--numbered-dirs`` and

=== modified file 'bzrlib/delta.py'
--- bzrlib/delta.py	2007-05-02 11:02:46 +0000
+++ bzrlib/delta.py	2007-07-28 22:45:28 +0000
@@ -217,7 +217,7 @@
 
 def _compare_trees(old_tree, new_tree, want_unchanged, specific_files,
                    include_root, extra_trees=None,
-                   want_unversioned=False):
+                   require_versioned=False, want_unversioned=False):
     """Worker function that implements Tree.changes_from."""
     delta = TreeDelta()
     # mutter('start compare_trees')
@@ -225,6 +225,7 @@
     for (file_id, path, content_change, versioned, parent_id, name, kind,
          executable) in new_tree._iter_changes(old_tree, want_unchanged,
             specific_files, extra_trees=extra_trees,
+            require_versioned=require_versioned,
             want_unversioned=want_unversioned):
         if versioned == (False, False):
             delta.unversioned.append((path[1], None, kind[1]))

=== modified file 'bzrlib/tests/test_tree.py'
--- bzrlib/tests/test_tree.py	2007-03-02 03:47:56 +0000
+++ bzrlib/tests/test_tree.py	2007-07-31 19:42:15 +0000
@@ -16,6 +16,7 @@
 
 """Tests for Tree and InterTree."""
 
+from bzrlib import errors
 from bzrlib.tests import TestCaseWithTransport
 from bzrlib.tree import InterTree
 
@@ -120,3 +121,20 @@
         delta = wt.changes_from(wt.basis_tree(), wt, include_root=True)
         self.assertEqual(len(delta.added), 1)
         self.assertEqual(delta.added[0][0], '')
+
+    def test_changes_from_with_require_versioned(self):
+        """Ensure the require_versioned option does what's expected."""
+        wt = self.make_branch_and_tree('.')
+        self.build_tree(['known_file', 'unknown_file'])
+        wt.add('known_file')
+
+        self.assertRaises(errors.PathsNotVersionedError,
+            wt.changes_from, wt.basis_tree(), wt, specific_files=['known_file',
+            'unknown_file'], require_versioned=True)
+
+        # we need to pass a known file with an unknown file to get this to
+        # fail when expected.
+        delta = wt.changes_from(wt.basis_tree(), wt, 
+            specific_files=['known_file', 'unknown_file'] ,
+            require_versioned=False)
+        self.assertEqual(len(delta.added), 1)

=== modified file 'bzrlib/tree.py'
--- bzrlib/tree.py	2007-07-19 15:44:17 +0000
+++ bzrlib/tree.py	2007-07-28 22:45:28 +0000
@@ -611,6 +611,7 @@
             return result
         return delta._compare_trees(self.source, self.target, want_unchanged,
             specific_files, include_root, extra_trees=extra_trees,
+            require_versioned=require_versioned,
             want_unversioned=want_unversioned)
 
     def _iter_changes(self, include_unchanged=False,

